@@ -50,11 +50,21 @@ extern time_t rss_updated;
 extern feedPtr searchFeed;
 
 static void free_iap_type();
+static void display_handler(osso_display_state_t state, gpointer data);
+
+extern progress_bar_mode progressbar_mode_prev;
+
+
+extern Iphb_cb_data iphb_data; // Rama added
 
 gboolean _rss_dbus_signal_applet(gchar * signal);
 osso_application_top_cb_f *osso_top_callback(const gchar * arguments,
                                              AppData * app_data);
 
+gint event_delete(gpointer data);
+gint
+_register_alarmd(gpointer data);
+
 /************************************************************************/
 /*                        PRIVATE FUNCTIONS                             */
 /************************************************************************/
@@ -491,6 +501,89 @@ gint dbus_req_handler(const gchar * interface,
     return dbus_message_handler(method, arguments, data, retval);
 }
 
+gboolean poll_iphb_fd(gpointer data)
+{
+	fd_set fds;
+	struct timeval time_wait;
+	GConfClient* gconf = gconf_client_get_default();
+	int iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);
+	time_t cur_time = 0;
+
+	memset(&time_wait, 0, sizeof(struct timeval));
+
+	time_wait.tv_sec = 60;
+	time_wait.tv_usec = 0;
+
+	if(0 >= iphb_fd) {
+		return TRUE;
+	}
+
+	if(1/*CHECK IF DISPLAY IS ON */) {
+		FD_ZERO(&fds);
+		FD_SET((unsigned int)iphb_fd, &fds);
+		if(select(iphb_fd+1,&fds,NULL,NULL,&time_wait)) {
+			if( FD_ISSET(iphb_fd,&fds) ) {
+				/* DO REFRESH */
+				ULOG_DEBUG("\n\n\n******It's refresh time*******\n\n\n");
+				app_data->app_ui_data->auto_refresh_is_ongoing = TRUE;
+				app_data->app_ui_data->iap_action = OSSO_IAP_REFRESH_ALL_NO_DIALOG;
+				cur_time = time(NULL);
+				gconf_client_set_int(gconf, RSS_SETTINGS_IPHB_LAST_REFRESH_TIME, cur_time, NULL);
+				
+				setup_alarm_event(TRUE, &iphb_data);
+				iphb_data.source_id = setup_iphb_callback(&iphb_data);
+				if (ui_feedlist_auto_update(NULL)) {
+					if (app_data->app_ui_data->start_on_background) {
+						on_quit(FALSE);
+					}
+				}
+
+				/*retval->type = DBUS_TYPE_INVALID;
+				osso_rpc_free_val(retval);*/
+				return FALSE;	
+			}
+			else {
+				return FALSE;
+			}
+		}
+	}
+	return FALSE;
+}
+
+
+static void display_handler(osso_display_state_t state, gpointer data)
+{
+	if(state == OSSO_DISPLAY_OFF)
+	{
+		app_data->app_ui_data->display_off = TRUE;
+	}
+	else if(state == OSSO_DISPLAY_ON)
+	{
+		//TRUE
+	    ULOG_DEBUG("\n#### RSS Couldn't set HW event handler ********TRUE****\n");
+		app_data->app_ui_data->display_off = FALSE;
+		if(app_data->app_ui_data->application_topped == TRUE)
+		{
+			if(app_data->app_ui_data->update_feed_list_needed == TRUE)
+			{
+				ui_feedlist_update();
+				app_data->app_ui_data->update_feed_list_needed = FALSE;
+			}
+			if(app_data->app_ui_data->update_progress_needed == TRUE)
+			{
+				ULOG_DEBUG("\n####Before calling  switch_progressbar********TRUE****\n");
+				switch_progressbar(progressbar_mode_prev);
+				app_data->app_ui_data->update_progress_needed = FALSE;
+			}
+		        if( app_data->app_ui_data->call_ui_mainwindow_finish_needed == TRUE)
+               		{
+				call_ui_mainwindow_finish(NULL);
+				app_data->app_ui_data->call_ui_mainwindow_finish_needed = FALSE;				
+			}
+		}	
+	}
+}
+
 gint dbus_message_handler(const gchar * method,
                           GArray * arguments,
                           gpointer data, osso_rpc_t * retval)
@@ -605,7 +698,7 @@ gint dbus_message_handler(const gchar * method,
         ULOG_DEBUG("\n\n\n******It's refresh time*******\n\n\n");
         app_data->app_ui_data->auto_refresh_is_ongoing = TRUE;
         if (ui_feedlist_auto_update(NULL)) {
-            setup_alarm_event(FALSE);
+            //setup_alarm_event(FALSE);
             if (app_ui_data->start_on_background) {
                 on_quit(FALSE);
             }
@@ -687,10 +780,15 @@ gint dbus_message_handler(const gchar * method,
   
  	g_free(filename);
 
-       if( (app_ui_data->start_alarmdel_on_background) || (app_ui_data->start_on_background) ) {
+       if( (app_ui_data->start_alarmdel_on_background) && (app_ui_data->start_on_background) ) {
                 delete_allalarm_events();
                 on_quit_cb(NULL);
        }
+       if( (!app_data->app_ui_data->start_alarmdel_on_background) && (!app_data->app_ui_data->start_on_background) ) {
+		g_timeout_add(100, event_delete, NULL);
+		g_timeout_add(100, _register_alarmd, NULL);       
+       }
+
     }
 
     else {
@@ -702,6 +800,45 @@ gint dbus_message_handler(const gchar * method,
 
 extern gboolean lifereaStarted;
 
+gint event_delete(gpointer data)
+{
+	if( (!app_data->app_ui_data->start_alarmdel_on_background) && (!app_data->app_ui_data->start_on_background) ) {
+		close_iphb_handle(iphb_data);
+		remove_iphb_callback(iphb_data.source_id);
+		iphb_data.source_id = 0;
+	}	
+	return FALSE;
+}
+
+gint
+_register_alarmd(gpointer data)
+{
+	if( (!app_data->app_ui_data->start_alarmdel_on_background) && (!app_data->app_ui_data->start_on_background) ) {
+		iphb_data.iphb_callback = (GSourceFunc)(poll_iphb_fd);
+		iphb_data.source_id = 0;
+		setup_alarm_event_now(TRUE, &iphb_data);    // Rama - commented
+		iphb_data.source_id = setup_iphb_callback(&iphb_data);
+	}	    
+	return FALSE;
+}
+#if 0
+/* This part of code will disable IPHB if display goes OFF.
+   * eventually network will not refresh if device is sleeping.
+   * Hence disabling the code for now. - Rama */
+
+static void display_handler(osso_display_state_t state, gpointer data)
+{
+	if (state == OSSO_DISPLAY_OFF)
+	{
+		g_timeout_add(100, event_delete, NULL);
+	}
+	else if( state == OSSO_DISPLAY_ON )
+	{
+		g_timeout_add(100, _register_alarmd, NULL);
+	}
+}
+#endif 
+
 /* Depending on the state of hw, do something */
 void hw_event_handler(osso_hw_state_t * state, gpointer data)
 {
@@ -776,7 +913,7 @@ void hw_event_handler(osso_hw_state_t * state, gpointer data)
  * dbus-message handling callbaks, and hw-event callbacks. */
 gboolean init_osso(AppData * app_data)
 {
-    osso_return_t ret, ret2;
+    osso_return_t ret, ret2,retval_display;
     GError *error = NULL;
 
     g_assert(app_data != NULL);
@@ -823,6 +960,19 @@ gboolean init_osso(AppData * app_data)
         ULOG_CRIT("Could not set callback for HW monitoring");
     }
 
+    /* This part of code will disable IPHB if display goes OFF.
+     * eventually network will not refresh if device is sleeping.
+     * Hence disabling the code for now. - Rama */
+    /*ret = osso_hw_set_display_event_cb(app_data->osso, display_handler , NULL);
+    if( ret != OSSO_OK ) {
+	    g_warning( "Couldn't set hw event handler (%d)", ret );
+    }*/	
+
+	//Register the display handler
+     retval_display = osso_hw_set_display_event_cb(app_data->osso,display_handler,app_data);   
+     if(retval_display != OSSO_OK)
+    ULOG_DEBUG("\n#### RSS Couldn't set HW event handler (%d)",retval_display);	
+	 
     iap = con_ic_connection_new();
     if (!iap) {
         ULOG_CRIT("Could not set callback for connectivity");
