@@ -691,14 +691,26 @@ folderPtr ui_feedlist_get_target_folder()
 
 void ui_feedlist_update_iter(GtkTreeIter * iter)
 {
-    rss_max_feed = 0;
-
-    ui_feedlist_update_(iter);
-
-    if (filter_feeds_without_unread_headlines)
-        gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(filter));
-
-    gtk_widget_queue_draw(feedlist);
+   g_assert(app_data);
+   g_assert(app_data->app_ui_data);
+   AppUIData *app_ui_data = app_data->app_ui_data;
+    if ((app_data->app_ui_data->application_topped == TRUE) && (app_data->app_ui_data->display_off == FALSE))
+    {
+        rss_max_feed = 0;
+    
+        ui_feedlist_update_(iter);
+    
+        if (filter_feeds_without_unread_headlines)
+            gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(filter));
+    
+        gtk_widget_queue_draw(feedlist);
+	app_data->app_ui_data->update_feed_list_needed = FALSE;	 	
+    }	
+    else
+    {
+    	app_data->app_ui_data->update_feed_list_needed = TRUE;
+	return;	
+    }
 }
 
 void rss_feed_tree_model_init(GtkTreeModelIface * iface, gpointer user_data)
@@ -1541,7 +1553,7 @@ gboolean ui_feedlist_auto_update(void *data)
 	 /*NB#106690*/   
         //if (app_data->app_ui_data->network_iap)
         {
-            app_data->app_ui_data->iap_action = OSSO_IAP_REFRESH_NO_DIALOG;
+            app_data->app_ui_data->iap_action = OSSO_IAP_REFRESH_ALL_NO_DIALOG/*OSSO_IAP_REFRESH_NO_DIALOG*/;
             request_iap_connect();
 	    return FALSE;
         }
